@@ -1,6 +1,6 @@
 from time import sleep, time
 from copy import deepcopy
-from .crypt import *
+from .crypted import *
 from .kry import *
 from .file import *
 from .lang_list import *
